@@ -1,6 +1,6 @@
 package DNS::Oterica::App;
 # ABSTRACT: the code behind `dnsoterica`
-$DNS::Oterica::App::VERSION = '0.311';
+$DNS::Oterica::App::VERSION = '0.312';
 use Moose;
 use DNS::Oterica::Hub;
 use File::Find::Rule;
@@ -129,7 +129,17 @@ DNS::Oterica::App - the code behind `dnsoterica`
 
 =head1 VERSION
 
-version 0.311
+version 0.312
+
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 ATTRIBUTES
 
@@ -146,11 +156,11 @@ for hosts.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
