@@ -1,6 +1,6 @@
 package DNS::Oterica::Node;
 # ABSTRACT: DNSO node. belongs to families. 
-$DNS::Oterica::Node::VERSION = '0.311';
+$DNS::Oterica::Node::VERSION = '0.312';
 use Moose;
 
 use DNS::Oterica::Role::RecordMaker;
@@ -99,7 +99,7 @@ DNS::Oterica::Node - DNSO node. belongs to families.
 
 =head1 VERSION
 
-version 0.311
+version 0.312
 
 =head1 OVERVIEW
 
@@ -108,6 +108,16 @@ zero or more families.
 
 Like other DNS::Oterica objects, they should be created through the hub.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 domain
@@ -145,11 +155,11 @@ By default, it returns nothing.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
