@@ -1,6 +1,6 @@
 package DNS::Oterica::Role::RecordMaker;
 # ABSTRACT: a delegation class for the DNSO recordmaker.
-$DNS::Oterica::Role::RecordMaker::VERSION = '0.311';
+$DNS::Oterica::Role::RecordMaker::VERSION = '0.312';
 use Moose::Role;
 
 use DNS::Oterica::RecordMaker::TinyDNS;
@@ -37,13 +37,23 @@ DNS::Oterica::Role::RecordMaker - a delegation class for the DNSO recordmaker.
 
 =head1 VERSION
 
-version 0.311
+version 0.312
 
 =head1 DESCRIPTION
 
 C<DNS::Oterica::Role::RecordMaker> delegates to an underlying record maker. It
 exposes this record maker with its C<rec> method.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 rec
@@ -52,11 +62,11 @@ The record maker, e.g. L<DNS::Oterica::RecordMaker::TinyDNS>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
